==> v2.2.0.zip: pdf_tech_back_end/pdf-tech-core/src/main/java/cn/kdan/pdf/tech/core/model/VppMember.java <==
package cn.kdan.pdf.tech.core.model;

import java.io.Serializable;
import java.util.Date;

public class VppMember implements Serializable {
    private String id;

    private String email;

    private String fullName;

    private Integer subscriberType;

    private Date createdAt;

    private Date updatedAt;

    private Integer subscribed;

    private String digestPassword;

    private String phone;

    private String validFlag;

    private String industry;

    private String companyId;

    private Integer lastPopularizeAt;

    private Date lastPresentedCouponAt;

    private Integer mailable;

    private Integer resetToken;

    private String role;

    private String job;

    private String area;

    private static final long serialVersionUID = 1L;

    public String getId() {
        return id;
    }

    public VppMember withId(String id) {
        this.setId(id);
        return this;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getEmail() {
        return email;
    }

    public VppMember withEmail(String email) {
        this.setEmail(email);
        return this;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getFullName() {
        return fullName;
    }

    public VppMember withFullName(String fullName) {
        this.setFullName(fullName);
        return this;
    }

    public void setFullName(String fullName) {
        this.fullName = fullName;
    }

    public Integer getSubscriberType() {
        return subscriberType;
    }

    public VppMember withSubscriberType(Integer subscriberType) {
        this.setSubscriberType(subscriberType);
        return this;
    }

    public void setSubscriberType(Integer subscriberType) {
        this.subscriberType = subscriberType;
    }

    public Date getCreatedAt() {
        return createdAt;
    }

    public VppMember withCreatedAt(Date createdAt) {
        this.setCreatedAt(createdAt);
        return this;
    }

    public void setCreatedAt(Date createdAt) {
        this.createdAt = createdAt;
    }

    public Date getUpdatedAt() {
        return updatedAt;
    }

    public VppMember withUpdatedAt(Date updatedAt) {
        this.setUpdatedAt(updatedAt);
        return this;
    }

    public void setUpdatedAt(Date updatedAt) {
        this.updatedAt = updatedAt;
    }

    public Integer getSubscribed() {
        return subscribed;
    }

    public VppMember withSubscribed(Integer subscribed) {
        this.setSubscribed(subscribed);
        return this;
    }

    public void setSubscribed(Integer subscribed) {
        this.subscribed = subscribed;
    }

    public String getDigestPassword() {
        return digestPassword;
    }

    public VppMember withDigestPassword(String digestPassword) {
        this.setDigestPassword(digestPassword);
        return this;
    }

    public void setDigestPassword(String digestPassword) {
        this.digestPassword = digestPassword;
    }

    public String getPhone() {
        return phone;
    }

    public VppMember withPhone(String phone) {
        this.setPhone(phone);
        return this;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getValidFlag() {
        return validFlag;
    }

    public VppMember withValidFlag(String validFlag) {
        this.setValidFlag(validFlag);
        return this;
    }

    public void setValidFlag(String validFlag) {
        this.validFlag = validFlag;
    }

    public String getIndustry() {
        return industry;
    }

    public VppMember withIndustry(String industry) {
        this.setIndustry(industry);
        return this;
    }

    public void setIndustry(String industry) {
        this.industry = industry;
    }

    public String getCompanyId() {
        return companyId;
    }

    public VppMember withCompanyId(String companyId) {
        this.setCompanyId(companyId);
        return this;
    }

    public void setCompanyId(String companyId) {
        this.companyId = companyId;
    }

    public Integer getLastPopularizeAt() {
        return lastPopularizeAt;
    }

    public VppMember withLastPopularizeAt(Integer lastPopularizeAt) {
        this.setLastPopularizeAt(lastPopularizeAt);
        return this;
    }

    public void setLastPopularizeAt(Integer lastPopularizeAt) {
        this.lastPopularizeAt = lastPopularizeAt;
    }

    public Date getLastPresentedCouponAt() {
        return lastPresentedCouponAt;
    }

    public VppMember withLastPresentedCouponAt(Date lastPresentedCouponAt) {
        this.setLastPresentedCouponAt(lastPresentedCouponAt);
        return this;
    }

    public void setLastPresentedCouponAt(Date lastPresentedCouponAt) {
        this.lastPresentedCouponAt = lastPresentedCouponAt;
    }

    public Integer getMailable() {
        return mailable;
    }

    public VppMember withMailable(Integer mailable) {
        this.setMailable(mailable);
        return this;
    }

    public void setMailable(Integer mailable) {
        this.mailable = mailable;
    }

    public Integer getResetToken() {
        return resetToken;
    }

    public VppMember withResetToken(Integer resetToken) {
        this.setResetToken(resetToken);
        return this;
    }

    public void setResetToken(Integer resetToken) {
        this.resetToken = resetToken;
    }

    public String getRole() {
        return role;
    }

    public VppMember withRole(String role) {
        this.setRole(role);
        return this;
    }

    public void setRole(String role) {
        this.role = role;
    }

    public String getJob() {
        return job;
    }

    public VppMember withJob(String job) {
        this.setJob(job);
        return this;
    }

    public void setJob(String job) {
        this.job = job;
    }

    public String getArea() {
        return area;
    }

    public VppMember withArea(String area) {
        this.setArea(area);
        return this;
    }

    public void setArea(String area) {
        this.area = area;
    }

    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        VppMember other = (VppMember) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getEmail() == null ? other.getEmail() == null : this.getEmail().equals(other.getEmail()))
            && (this.getFullName() == null ? other.getFullName() == null : this.getFullName().equals(other.getFullName()))
            && (this.getSubscriberType() == null ? other.getSubscriberType() == null : this.getSubscriberType().equals(other.getSubscriberType()))
            && (this.getCreatedAt() == null ? other.getCreatedAt() == null : this.getCreatedAt().equals(other.getCreatedAt()))
            && (this.getUpdatedAt() == null ? other.getUpdatedAt() == null : this.getUpdatedAt().equals(other.getUpdatedAt()))
            && (this.getSubscribed() == null ? other.getSubscribed() == null : this.getSubscribed().equals(other.getSubscribed()))
            && (this.getDigestPassword() == null ? other.getDigestPassword() == null : this.getDigestPassword().equals(other.getDigestPassword()))
            && (this.getPhone() == null ? other.getPhone() == null : this.getPhone().equals(other.getPhone()))
            && (this.getValidFlag() == null ? other.getValidFlag() == null : this.getValidFlag().equals(other.getValidFlag()))
            && (this.getIndustry() == null ? other.getIndustry() == null : this.getIndustry().equals(other.getIndustry()))
            && (this.getCompanyId() == null ? other.getCompanyId() == null : this.getCompanyId().equals(other.getCompanyId()))
            && (this.getLastPopularizeAt() == null ? other.getLastPopularizeAt() == null : this.getLastPopularizeAt().equals(other.getLastPopularizeAt()))
            && (this.getLastPresentedCouponAt() == null ? other.getLastPresentedCouponAt() == null : this.getLastPresentedCouponAt().equals(other.getLastPresentedCouponAt()))
            && (this.getMailable() == null ? other.getMailable() == null : this.getMailable().equals(other.getMailable()))
            && (this.getResetToken() == null ? other.getResetToken() == null : this.getResetToken().equals(other.getResetToken()))
            && (this.getRole() == null ? other.getRole() == null : this.getRole().equals(other.getRole()))
            && (this.getJob() == null ? other.getJob() == null : this.getJob().equals(other.getJob()))
            && (this.getArea() == null ? other.getArea() == null : this.getArea().equals(other.getArea()));
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getEmail() == null) ? 0 : getEmail().hashCode());
        result = prime * result + ((getFullName() == null) ? 0 : getFullName().hashCode());
        result = prime * result + ((getSubscriberType() == null) ? 0 : getSubscriberType().hashCode());
        result = prime * result + ((getCreatedAt() == null) ? 0 : getCreatedAt().hashCode());
        result = prime * result + ((getUpdatedAt() == null) ? 0 : getUpdatedAt().hashCode());
        result = prime * result + ((getSubscribed() == null) ? 0 : getSubscribed().hashCode());
        result = prime * result + ((getDigestPassword() == null) ? 0 : getDigestPassword().hashCode());
        result = prime * result + ((getPhone() == null) ? 0 : getPhone().hashCode());
        result = prime * result + ((getValidFlag() == null) ? 0 : getValidFlag().hashCode());
        result = prime * result + ((getIndustry() == null) ? 0 : getIndustry().hashCode());
        result = prime * result + ((getCompanyId() == null) ? 0 : getCompanyId().hashCode());
        result = prime * result + ((getLastPopularizeAt() == null) ? 0 : getLastPopularizeAt().hashCode());
        result = prime * result + ((getLastPresentedCouponAt() == null) ? 0 : getLastPresentedCouponAt().hashCode());
        result = prime * result + ((getMailable() == null) ? 0 : getMailable().hashCode());
        result = prime * result + ((getResetToken() == null) ? 0 : getResetToken().hashCode());
        result = prime * result + ((getRole() == null) ? 0 : getRole().hashCode());
        result = prime * result + ((getJob() == null) ? 0 : getJob().hashCode());
        result = prime * result + ((getArea() == null) ? 0 : getArea().hashCode());
        return result;
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", email=").append(email);
        sb.append(", fullName=").append(fullName);
        sb.append(", subscriberType=").append(subscriberType);
        sb.append(", createdAt=").append(createdAt);
        sb.append(", updatedAt=").append(updatedAt);
        sb.append(", subscribed=").append(subscribed);
        sb.append(", digestPassword=").append(digestPassword);
        sb.append(", phone=").append(phone);
        sb.append(", validFlag=").append(validFlag);
        sb.append(", industry=").append(industry);
        sb.append(", companyId=").append(companyId);
        sb.append(", lastPopularizeAt=").append(lastPopularizeAt);
        sb.append(", lastPresentedCouponAt=").append(lastPresentedCouponAt);
        sb.append(", mailable=").append(mailable);
        sb.append(", resetToken=").append(resetToken);
        sb.append(", role=").append(role);
        sb.append(", job=").append(job);
        sb.append(", area=").append(area);
        sb.append(", serialVersionUID=").append(serialVersionUID);
        sb.append("]");
        return sb.toString();
    }
}

==> v3.0.1.zip: pdf_tech_back_end/pdf-tech-core/src/main/java/cn/kdan/pdf/tech/core/model/VppMember.java <==
package cn.kdan.pdf.tech.core.model;

import java.io.Serializable;
import java.util.Date;

public class VppMember implements Serializable {
    private String id;

    private String email;

    private String fullName;

    private Integer subscriberType;

    private Date createdAt;

    private Date updatedAt;

    private Integer subscribed;

    private String digestPassword;

    private String phone;

    private String validFlag;

    private String industry;

    private String companyId;

    private Integer lastPopularizeAt;

    private Date lastPresentedCouponAt;

    private Integer mailable;

    private Integer resetToken;

    private String role;

    private String job;

    private String area;

    private String isSso;

    private String directoryId;

    private Date loginTime;

    private Date adminConsoleLoginTime;

    private static final long serialVersionUID = 1L;

    public String getId() {
        return id;
    }

    public VppMember withId(String id) {
        this.setId(id);
        return this;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getEmail() {
        return email;
    }

    public VppMember withEmail(String email) {
        this.setEmail(email);
        return this;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getFullName() {
        return fullName;
    }

    public VppMember withFullName(String fullName) {
        this.setFullName(fullName);
        return this;
    }

    public void setFullName(String fullName) {
        this.fullName = fullName;
    }

    public Integer getSubscriberType() {
        return subscriberType;
    }

    public VppMember withSubscriberType(Integer subscriberType) {
        this.setSubscriberType(subscriberType);
        return this;
    }

    public void setSubscriberType(Integer subscriberType) {
        this.subscriberType = subscriberType;
    }

    public Date getCreatedAt() {
        return createdAt;
    }

    public VppMember withCreatedAt(Date createdAt) {
        this.setCreatedAt(createdAt);
        return this;
    }

    public void setCreatedAt(Date createdAt) {
        this.createdAt = createdAt;
    }

    public Date getUpdatedAt() {
        return updatedAt;
    }

    public VppMember withUpdatedAt(Date updatedAt) {
        this.setUpdatedAt(updatedAt);
        return this;
    }

    public void setUpdatedAt(Date updatedAt) {
        this.updatedAt = updatedAt;
    }

    public Integer getSubscribed() {
        return subscribed;
    }

    public VppMember withSubscribed(Integer subscribed) {
        this.setSubscribed(subscribed);
        return this;
    }

    public void setSubscribed(Integer subscribed) {
        this.subscribed = subscribed;
    }

    public String getDigestPassword() {
        return digestPassword;
    }

    public VppMember withDigestPassword(String digestPassword) {
        this.setDigestPassword(digestPassword);
        return this;
    }

    public void setDigestPassword(String digestPassword) {
        this.digestPassword = digestPassword;
    }

    public String getPhone() {
        return phone;
    }

    public VppMember withPhone(String phone) {
        this.setPhone(phone);
        return this;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getValidFlag() {
        return validFlag;
    }

    public VppMember withValidFlag(String validFlag) {
        this.setValidFlag(validFlag);
        return this;
    }

    public void setValidFlag(String validFlag) {
        this.validFlag = validFlag;
    }

    public String getIndustry() {
        return industry;
    }

    public VppMember withIndustry(String industry) {
        this.setIndustry(industry);
        return this;
    }

    public void setIndustry(String industry) {
        this.industry = industry;
    }

    public String getCompanyId() {
        return companyId;
    }

    public VppMember withCompanyId(String companyId) {
        this.setCompanyId(companyId);
        return this;
    }

    public void setCompanyId(String companyId) {
        this.companyId = companyId;
    }

    public Integer getLastPopularizeAt() {
        return lastPopularizeAt;
    }

    public VppMember withLastPopularizeAt(Integer lastPopularizeAt) {
        this.setLastPopularizeAt(lastPopularizeAt);
        return this;
    }

    public void setLastPopularizeAt(Integer lastPopularizeAt) {
        this.lastPopularizeAt = lastPopularizeAt;
    }

    public Date getLastPresentedCouponAt() {
        return lastPresentedCouponAt;
    }

    public VppMember withLastPresentedCouponAt(Date lastPresentedCouponAt) {
        this.setLastPresentedCouponAt(lastPresentedCouponAt);
        return this;
    }

    public void setLastPresentedCouponAt(Date lastPresentedCouponAt) {
        this.lastPresentedCouponAt = lastPresentedCouponAt;
    }

    public Integer getMailable() {
        return mailable;
    }

    public VppMember withMailable(Integer mailable) {
        this.setMailable(mailable);
        return this;
    }

    public void setMailable(Integer mailable) {
        this.mailable = mailable;
    }

    public Integer getResetToken() {
        return resetToken;
    }

    public VppMember withResetToken(Integer resetToken) {
        this.setResetToken(resetToken);
        return this;
    }

    public void setResetToken(Integer resetToken) {
        this.resetToken = resetToken;
    }

    public String getRole() {
        return role;
    }

    public VppMember withRole(String role) {
        this.setRole(role);
        return this;
    }

    public void setRole(String role) {
        this.role = role;
    }

    public String getJob() {
        return job;
    }

    public VppMember withJob(String job) {
        this.setJob(job);
        return this;
    }

    public void setJob(String job) {
        this.job = job;
    }

    public String getArea() {
        return area;
    }

    public VppMember withArea(String area) {
        this.setArea(area);
        return this;
    }

    public void setArea(String area) {
        this.area = area;
    }

    public String getIsSso() {
        return isSso;
    }

    public VppMember withIsSso(String isSso) {
        this.setIsSso(isSso);
        return this;
    }

    public void setIsSso(String isSso) {
        this.isSso = isSso;
    }

    public String getDirectoryId() {
        return directoryId;
    }

    public VppMember withDirectoryId(String directoryId) {
        this.setDirectoryId(directoryId);
        return this;
    }

    public void setDirectoryId(String directoryId) {
        this.directoryId = directoryId;
    }

    public Date getLoginTime() {
        return loginTime;
    }

    public VppMember withLoginTime(Date loginTime) {
        this.setLoginTime(loginTime);
        return this;
    }

    public void setLoginTime(Date loginTime) {
        this.loginTime = loginTime;
    }

    public Date getAdminConsoleLoginTime() {
        return adminConsoleLoginTime;
    }

    public VppMember withAdminConsoleLoginTime(Date adminConsoleLoginTime) {
        this.setAdminConsoleLoginTime(adminConsoleLoginTime);
        return this;
    }

    public void setAdminConsoleLoginTime(Date adminConsoleLoginTime) {
        this.adminConsoleLoginTime = adminConsoleLoginTime;
    }

    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        VppMember other = (VppMember) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getEmail() == null ? other.getEmail() == null : this.getEmail().equals(other.getEmail()))
            && (this.getFullName() == null ? other.getFullName() == null : this.getFullName().equals(other.getFullName()))
            && (this.getSubscriberType() == null ? other.getSubscriberType() == null : this.getSubscriberType().equals(other.getSubscriberType()))
            && (this.getCreatedAt() == null ? other.getCreatedAt() == null : this.getCreatedAt().equals(other.getCreatedAt()))
            && (this.getUpdatedAt() == null ? other.getUpdatedAt() == null : this.getUpdatedAt().equals(other.getUpdatedAt()))
            && (this.getSubscribed() == null ? other.getSubscribed() == null : this.getSubscribed().equals(other.getSubscribed()))
            && (this.getDigestPassword() == null ? other.getDigestPassword() == null : this.getDigestPassword().equals(other.getDigestPassword()))
            && (this.getPhone() == null ? other.getPhone() == null : this.getPhone().equals(other.getPhone()))
            && (this.getValidFlag() == null ? other.getValidFlag() == null : this.getValidFlag().equals(other.getValidFlag()))
            && (this.getIndustry() == null ? other.getIndustry() == null : this.getIndustry().equals(other.getIndustry()))
            && (this.getCompanyId() == null ? other.getCompanyId() == null : this.getCompanyId().equals(other.getCompanyId()))
            && (this.getLastPopularizeAt() == null ? other.getLastPopularizeAt() == null : this.getLastPopularizeAt().equals(other.getLastPopularizeAt()))
            && (this.getLastPresentedCouponAt() == null ? other.getLastPresentedCouponAt() == null : this.getLastPresentedCouponAt().equals(other.getLastPresentedCouponAt()))
            && (this.getMailable() == null ? other.getMailable() == null : this.getMailable().equals(other.getMailable()))
            && (this.getResetToken() == null ? other.getResetToken() == null : this.getResetToken().equals(other.getResetToken()))
            && (this.getRole() == null ? other.getRole() == null : this.getRole().equals(other.getRole()))
            && (this.getJob() == null ? other.getJob() == null : this.getJob().equals(other.getJob()))
            && (this.getArea() == null ? other.getArea() == null : this.getArea().equals(other.getArea()))
            && (this.getIsSso() == null ? other.getIsSso() == null : this.getIsSso().equals(other.getIsSso()))
            && (this.getDirectoryId() == null ? other.getDirectoryId() == null : this.getDirectoryId().equals(other.getDirectoryId()))
            && (this.getLoginTime() == null ? other.getLoginTime() == null : this.getLoginTime().equals(other.getLoginTime()))
            && (this.getAdminConsoleLoginTime() == null ? other.getAdminConsoleLoginTime() == null : this.getAdminConsoleLoginTime().equals(other.getAdminConsoleLoginTime()));
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getEmail() == null) ? 0 : getEmail().hashCode());
        result = prime * result + ((getFullName() == null) ? 0 : getFullName().hashCode());
        result = prime * result + ((getSubscriberType() == null) ? 0 : getSubscriberType().hashCode());
        result = prime * result + ((getCreatedAt() == null) ? 0 : getCreatedAt().hashCode());
        result = prime * result + ((getUpdatedAt() == null) ? 0 : getUpdatedAt().hashCode());
        result = prime * result + ((getSubscribed() == null) ? 0 : getSubscribed().hashCode());
        result = prime * result + ((getDigestPassword() == null) ? 0 : getDigestPassword().hashCode());
        result = prime * result + ((getPhone() == null) ? 0 : getPhone().hashCode());
        result = prime * result + ((getValidFlag() == null) ? 0 : getValidFlag().hashCode());
        result = prime * result + ((getIndustry() == null) ? 0 : getIndustry().hashCode());
        result = prime * result + ((getCompanyId() == null) ? 0 : getCompanyId().hashCode());
        result = prime * result + ((getLastPopularizeAt() == null) ? 0 : getLastPopularizeAt().hashCode());
        result = prime * result + ((getLastPresentedCouponAt() == null) ? 0 : getLastPresentedCouponAt().hashCode());
        result = prime * result + ((getMailable() == null) ? 0 : getMailable().hashCode());
        result = prime * result + ((getResetToken() == null) ? 0 : getResetToken().hashCode());
        result = prime * result + ((getRole() == null) ? 0 : getRole().hashCode());
        result = prime * result + ((getJob() == null) ? 0 : getJob().hashCode());
        result = prime * result + ((getArea() == null) ? 0 : getArea().hashCode());
        result = prime * result + ((getIsSso() == null) ? 0 : getIsSso().hashCode());
        result = prime * result + ((getDirectoryId() == null) ? 0 : getDirectoryId().hashCode());
        result = prime * result + ((getLoginTime() == null) ? 0 : getLoginTime().hashCode());
        result = prime * result + ((getAdminConsoleLoginTime() == null) ? 0 : getAdminConsoleLoginTime().hashCode());
        return result;
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", email=").append(email);
        sb.append(", fullName=").append(fullName);
        sb.append(", subscriberType=").append(subscriberType);
        sb.append(", createdAt=").append(createdAt);
        sb.append(", updatedAt=").append(updatedAt);
        sb.append(", subscribed=").append(subscribed);
        sb.append(", digestPassword=").append(digestPassword);
        sb.append(", phone=").append(phone);
        sb.append(", validFlag=").append(validFlag);
        sb.append(", industry=").append(industry);
        sb.append(", companyId=").append(companyId);
        sb.append(", lastPopularizeAt=").append(lastPopularizeAt);
        sb.append(", lastPresentedCouponAt=").append(lastPresentedCouponAt);
        sb.append(", mailable=").append(mailable);
        sb.append(", resetToken=").append(resetToken);
        sb.append(", role=").append(role);
        sb.append(", job=").append(job);
        sb.append(", area=").append(area);
        sb.append(", isSso=").append(isSso);
        sb.append(", directoryId=").append(directoryId);
        sb.append(", loginTime=").append(loginTime);
        sb.append(", adminConsoleLoginTime=").append(adminConsoleLoginTime);
        sb.append(", serialVersionUID=").append(serialVersionUID);
        sb.append("]");
        return sb.toString();
    }
}
